@@ -3,16 +3,15 @@ dn.py - misc stuff for handling distinguished names (see RFC 4514)
 
 See https://www.python-ldap.org/ for details.
 
-\$Id: dn.py,v 1.17 2017/08/15 16:21:58 stroeder Exp $
-
 Compability:
 - Tested with Python 2.0+
 """
 
-from ldap import __version__
-
+from ldap.pkginfo import __version__
 
 import _ldap
+assert _ldap.__version__==__version__, \
+       ImportError('ldap %s and _ldap %s version mismatch!' % (__version__,_ldap.__version__))
 
 import ldap.functions
 
