@@ -131,11 +131,13 @@ class SyncStateControl(ResponseControl):
         d = decoder.decode(encodedControlValue, asn1Spec = syncStateValue())
         state = d[0].getComponentByName('state')
         uuid = UUID(bytes=d[0].getComponentByName('entryUUID'))
-        self.cookie = d[0].getComponentByName('cookie')
+        cookie = d[0].getComponentByName('cookie')
+        if cookie.hasValue():
+            self.cookie = str(self.cookie)
+        else:
+            self.cookie = None
         self.state = self.__class__.opnames[int(state)]
         self.entryUUID = str(uuid)
-        if self.cookie is not None:
-            self.cookie = str(self.cookie)
 
 KNOWN_RESPONSE_CONTROLS[SyncStateControl.controlType] = SyncStateControl
 
@@ -165,12 +167,16 @@ class SyncDoneControl(ResponseControl):
 
     def decodeControlValue(self, encodedControlValue):
         d = decoder.decode(encodedControlValue, asn1Spec = syncDoneValue())
-        self.cookie = d[0].getComponentByName('cookie')
-        self.refreshDeletes = d[0].getComponentByName('refreshDeletes')
-        if self.cookie is not None:
-            self.cookie = str(self.cookie)
-        if self.refreshDeletes is not None:
-            self.refreshDeletes = bool(self.refreshDeletes)
+        cookie = d[0].getComponentByName('cookie')
+        if cookie.hasValue():
+            self.cookie = str(cookie)
+        else:
+            self.cookie = None
+        refresh_deletes = d[0].getComponentByName('refreshDeletes')
+        if refresh_deletes.hasValue():
+            self.refreshDeletes = bool(refresh_deletes)
+        else:
+            self.refreshDeletes = None
 
 KNOWN_RESPONSE_CONTROLS[SyncDoneControl.controlType] = SyncDoneControl
 
@@ -263,7 +269,7 @@ class SyncInfoMessage:
         for attr in [ 'newcookie', 'refreshDelete', 'refreshPresent', 'syncIdSet']:
             comp = d[0].getComponentByName(attr)
 
-            if comp is not None:
+            if comp.hasValue():
 
                 if attr == 'newcookie':
                     self.newcookie = str(comp)
@@ -272,7 +278,7 @@ class SyncInfoMessage:
                 val = dict()
 
                 cookie = comp.getComponentByName('cookie')
-                if cookie is not None:
+                if cookie.hasValue():
                     val['cookie'] = str(cookie)
 
                 if attr.startswith('refresh'):
